@@ -1,7 +1,7 @@
 package App::BencherUtils;
 
 our $DATE = '2016-01-22'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -508,15 +508,12 @@ sub list_bencher_results {
     my $resmeta = {};
     if ($args{fmt}) {
         require Bencher;
-        require Perinci::Result::Format::Lite;
 
         $resmeta->{'cmdline.skip_format'} = 1;
         my @content;
         for my $row (@rows) {
             push @content, "$row->{filename} (cpu: $row->{cpu}):\n";
-            my $res = Bencher::format_result($row->{res});
-            push @content, Perinci::Result::Format::Lite::format(
-                $res, "text-pretty");
+            push @content, Bencher::format_result($row->{res});
             push @content, "\n";
         }
         return [200, "OK", join("", @content), $resmeta];
@@ -546,7 +543,7 @@ App::BencherUtils - Utilities related to bencher
 
 =head1 VERSION
 
-This document describes version 0.08 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-01-22.
+This document describes version 0.09 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-01-22.
 
 =head1 SYNOPSIS
 
